@@ -116,6 +116,21 @@ renderDataTable = function(
         options$ajax$url = url
       }
       instance$x$options = fixServerOptions(options)
+
+      # We need to warn the use of "Select" extension in the server-side processing
+      # mode since right now there's no good way of supporting the server mode.
+      # More specifically, the Select ext can't remember the cross-page selections
+      # because the javascript implementation doesn't take the server mode into account.
+      # Until that gets changed, we are not able to integrate the Select ext with DT's
+      # own implementations.
+      if ('Select' %in% as.character(instance$x$extensions)) warning(
+        "The Select extension is not able to work with the server-side ",
+        "processing mode properly. It's recommended to use the Select extension ",
+        "only in the client-side processing mode (by setting `server = FALSE` ",
+        "in `DT::renderDT()`) or use DT's own selection implementations (",
+        "see the `selection` argument in ?DT::datatable).",
+        immediate. = TRUE, call. = FALSE
+      )
     }
 
     instance
@@ -277,7 +292,10 @@ selectCells = function(proxy, selected) {
 addRow = function(proxy, data) {
   if ((is.matrix(data) || is.data.frame(data)) && nrow(data) != 1)
     stop("'data' must be of only one row")
-  invokeRemote(proxy, 'addRow', list(as.list(unname(data)), I(rownames(data))))
+  # must apply unname() after as.list() because a data.table object
+  # can't be really unnamed. The names() attributes will be
+  # preserved but with empty strings (see #760).
+  invokeRemote(proxy, 'addRow', list(unname(as.list(data)), I(rownames(data))))
 }
 
 #' @rdname proxy
@@ -634,7 +652,9 @@ grep2 = function(pattern, x, ignore.case = FALSE, fixed = FALSE, ...) {
   # complete before it is sent to the server, in which case we do not search
   if (!fixed && inherits(try(grep(pattern, '', perl = TRUE), silent = TRUE), 'try-error'))
     return(seq_along(x))
-  grep(pattern, x, ignore.case = ignore.case, fixed = fixed, perl = TRUE, ...)
+  # #749 if both fixed and perl are TRUE, the latter will be ignored by R with
+  # an annoyed warning
+  grep(pattern, x, ignore.case = ignore.case, fixed = fixed, perl = !fixed, ...)
 }
 
 # filter a numeric/date/time vector using the search string "lower ... upper"
