@@ -7,7 +7,9 @@ shinyServer(function(input, output, session) {
   # selectRows() and selectColumns()
   output$foo = DT::renderDataTable(
     iris, server = FALSE, selection = list(target = 'row+column'),
-    caption = 'Using a proxy object to manipulate the table'
+    caption = 'Using a proxy object to manipulate the table',
+    extensions = 'ColReorder',
+    options = list(colReorder = TRUE)
   )
 
   proxy = dataTableProxy('foo')
@@ -36,6 +38,25 @@ shinyServer(function(input, output, session) {
     if (input$cap != '') proxy %>% updateCaption(input$cap)
   })
 
+  observe({
+    if (input$hide1) proxy %>% hideCols(3, TRUE)
+  })
+  observe({
+    if (input$show1) proxy %>% showCols(1, TRUE)
+  })
+  observe({
+    if (input$hide2) proxy %>% hideCols(c(1, 2))
+  })
+  observe({
+    if (input$show2) proxy %>% showCols(c(1, 2))
+  })
+  observe({
+    if (input$resetVis) proxy %>% hideCols(NULL, TRUE)
+  })
+  observe({
+    if (input$reverse) proxy %>% colReorder(5:0)
+  })
+
   output$info = renderPrint({
     list(rows = input$foo_rows_selected, columns = input$foo_columns_selected)
   })
